@@ -1,4 +1,3 @@
-// Paraselene generated this source file.
 package #1.#y#2;
 
 import paraselene.*;
@@ -31,7 +30,6 @@ setInitialized( true );
 }
 catch( Exception e ) {
 paraselene.supervisor.Option.debug( e );
-e.printStackTrace();
 }
 }
 /**
