@@ -34,6 +34,29 @@ public class Color extends PlainText implements AttributeValuable, CSSValuable {
 		setText( s );
 	}
 
+	private int toRGB( NumberValue num ) {
+		if ( num.getUnit() == NumberValue.Unit.PERCENTAGE ) {
+			num.multiply( 256 ).divide( 100 );
+		}
+		int	v = num.toInteger();
+		if ( v > 256 )	v = 255;
+		return v;
+	}
+
+	private boolean set_rgb_text( String str ){
+		String[]	all = str.split( "[\\(\\)]" );
+		if ( all.length != 2 )	return false;
+		if ( !"rgb".equalsIgnoreCase( all[0].trim() ) )	return false;
+		String[]	rgb = all[1].split( "," );
+		if ( rgb.length != 3 )	return false;
+		NumberValue[]	num = new NumberValue[3];
+		for ( int i = 0; i < 3; i++ ) {
+			num[i] = new NumberValue( rgb[i] );
+		}
+		setColor( toRGB( num[0] ), toRGB( num[1] ), toRGB( num[2] ) );
+		return true;
+	}
+
 	/**
 	 * 色の設定。
 	 * @param s 文字列。
@@ -48,19 +71,26 @@ public class Color extends PlainText implements AttributeValuable, CSSValuable {
 			super.setText( s );
 			return;
 		}
+		if ( set_rgb_text( s ) )	return;
 		if ( s.charAt( 0 ) != '#' ) {
 			setColor( WebColor.valueOf( s.toUpperCase() ) );
 			return;
 		}
-		char[]	org = s.toCharArray();
-		char[]	ch = new char[7];
-		int	org_len = org.length - 1;
-		int	ch_len = ch.length - 1;
-		for ( ; org_len >= 1 && ch_len >= 1; org_len--, ch_len-- ) ch[ch_len] = org[org_len];
-		for ( ; ch_len >= 1; ch_len-- )	ch[ch_len] = '0';
-		setColor( Integer.parseInt( new String( ch, 1, 2 ), 16 ),
-			Integer.parseInt( new String( ch, 3, 2 ), 16 ),
-			Integer.parseInt( new String( ch, 5, 2 ), 16 ) );
+		char[]	ch = s.substring( 1 ).toCharArray();
+		int[]	rgb = new int[3];
+		if ( ch.length == 3 ) {
+			for ( int i = 0; i < 3; i++ ) {
+				StringBuilder	buf = new StringBuilder( ch[i] );
+				buf = buf.append( ch[i] );
+				rgb[i] = Integer.parseInt( buf.toString(), 16 );
+			}
+		}
+		else {
+			for ( int i = 0; i < 3; i++ ) {
+				rgb[i] = Integer.parseInt( new String( ch, i * 2, 2 ), 16 );
+			}
+		}
+		setColor( rgb[0], rgb[1], rgb[2] );
 	}
 
 	/**
