@@ -19,13 +19,24 @@ import paraselene.css.*;
  * URIを示す文字列は、url(xxx) 形式の文字列を渡すと、内部の xxx だけ取り出します。
  */
 public class URIValue extends PlainText implements AttributeValuable, CSSValuable {
-	private static final long serialVersionUID = 2L;
+	private static final long serialVersionUID = 21L;
 	private static final String DOWNLOAD_DIR = "rabbit/";
+	private boolean feedback_f = false;
 	/**
 	 * デフォルトのエンコード(UTF-8)。
 	 */
 	public static final String DEFAULT_ENC = "UTF-8";
 
+	/**
+	 * 通常のページへのパスであるか？以下の場合に true となります。<br>
+	 * Paraselene のページを示す、且つ、相対パスである、
+	 * 且つ、ダウンロード用パスではない。
+	 * @return 上記参照。
+	 */
+	public boolean isParaselenePagePath() {
+		return feedback_f;
+	}
+
 	private URIValue() {}
 
 	private String out_enc = null;
@@ -196,11 +207,13 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 */
 	public void setURI( URI u, String dec ) throws UnsupportedEncodingException {
 		if ( u == null ) {
+			feedback_f = false;
 			setText( null );
 		}
 		else {
 			if ( dec == null )	dec = DEFAULT_ENC;
 			setText( URLDecoder.decode( u.toString(), dec ) );
+			feedback_f = super.toString( StringMode.PLAIN ).indexOf( Supervisor.LINK_DEF[0] ) == 0;
 		}
 	}
 
