@@ -122,33 +122,10 @@ class SaxContainer {
 			buf = buf.append( data[i] );
 			last_part = null;
 		}
-/**
-		if ( "noframes".equals( name ) ) {
-			StringBuilder	sub = new StringBuilder( "<body name='body'>" );
-			sub = sub.append( buf );
-			sub = sub.append( "</body>" );
-			DynamicPage	sub_page = pp.makePage();
-			try {
-				sub_page.create( sub.toString() );
-				Tag	body = sub_page.getTag( "body" );
-				int	cnt = body.getHTMLPartCount();
-				for ( int i = 0; i < cnt; i++ ) {
-					HTMLPart	p = body.getHTMLPart( 0 );
-					body.removeHTMLPart( 0 );
-					tag.addHTMLPart( p );
-				}
-			}
-			catch( DynamicPageException e ) {
-				e.printStackTrace();
-			}
-		}
-**/
-//		else {
-			String	str = buf.toString();
-			if ( crlf_f )	str = str.trim();
-			if ( str.isEmpty() )	return;
-			add( pp.makeText( str ) );
-//		}
+		String	str = buf.toString();
+		if ( crlf_f )	str = str.trim();
+		if ( str.isEmpty() )	return;
+		add( pp.makeText( str ) );
 	}
 
 }
