@@ -32,9 +32,10 @@ class JavaDefine {
 	static boolean isDefine( String str, boolean part_ck ) {
 		char[]	ch = str.toCharArray();
 		if ( !Character.isJavaIdentifierStart( ch[0] ) )	return true;
-		if ( !part_ck )	return false;
-		for ( int j = 1; j < ch.length; j++ ) {
-			if ( !Character.isJavaIdentifierPart( ch[j] ) )	return true;
+		if ( part_ck ) {
+			for ( int j = 1; j < ch.length; j++ ) {
+				if ( !Character.isJavaIdentifierPart( ch[j] ) )	return true;
+			}
 		}
 		return	map.get( str ) != null;
 	}
