@@ -25,7 +25,10 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			return Param.PACKAGE.get();
 		case 2:
 			buf = buf.append( "/**\n * Json\n */\nPARASELENE_JSON(-1),\n" );
-			buf = buf.append( "/**\n * Css\n */\nPARASELENE_CSS(-2),\n" );
+			buf = buf.append( "/**\n * FormJson\n */\nPARASELENE_FORM_JSON(-2),\n" );
+			buf = buf.append( "/**\n * Css\n */\nPARASELENE_CSS(-20),\n" );
+			buf = buf.append( "/**\n * Js\n */\nPARASELENE_JS(-21),\n" );
+			buf = buf.append( "/**\n * Resource\n */\nPARASELENE_RESOURCE(-30),\n" );
 			for ( int i = 0; i < cnt; i++ ) {
 				PrePage	page = page_map.get( org_html.get( i ) );
 				buf = buf.append( "/**\n * " );
@@ -44,6 +47,16 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			buf = buf.append( "pf.addDefine(PARASELENE_JSON,page.getClass());\n");
 			buf = buf.append( "map.put(PARASELENE_JSON.id,PARASELENE_JSON);\n" );
 			buf = buf.append( "pf.returnPage(page);\n" );
+
+			buf = buf.append( "page=new " );
+			buf = buf.append( Param.PACKAGE.get() );
+			buf = buf.append( "." );
+			buf = buf.append( Param.PACKAGE_BASE.get() );
+			buf = buf.append( ".FormJson();\n" );
+			buf = buf.append( "pf.addDefine(PARASELENE_FORM_JSON,page.getClass());\n");
+			buf = buf.append( "map.put(PARASELENE_FORM_JSON.id,PARASELENE_FORM_JSON);\n" );
+			buf = buf.append( "pf.returnPage(page);\n" );
+
 			buf = buf.append( "page=new " );
 			buf = buf.append( Param.PACKAGE.get() );
 			buf = buf.append( "." );
@@ -52,6 +65,25 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			buf = buf.append( "pf.addDefine(PARASELENE_CSS,page.getClass());\n");
 			buf = buf.append( "map.put(PARASELENE_CSS.id,PARASELENE_CSS);\n" );
 			buf = buf.append( "pf.returnPage(page);\n" );
+
+			buf = buf.append( "page=new " );
+			buf = buf.append( Param.PACKAGE.get() );
+			buf = buf.append( "." );
+			buf = buf.append( Param.PACKAGE_BASE.get() );
+			buf = buf.append( ".Js();\n" );
+			buf = buf.append( "pf.addDefine(PARASELENE_JS,page.getClass());\n");
+			buf = buf.append( "map.put(PARASELENE_JS.id,PARASELENE_JS);\n" );
+			buf = buf.append( "pf.returnPage(page);\n" );
+
+			buf = buf.append( "page=new " );
+			buf = buf.append( Param.PACKAGE.get() );
+			buf = buf.append( "." );
+			buf = buf.append( Param.PACKAGE_BASE.get() );
+			buf = buf.append( ".Resource();\n" );
+			buf = buf.append( "pf.addDefine(PARASELENE_RESOURCE,page.getClass());\n");
+			buf = buf.append( "map.put(PARASELENE_RESOURCE.id,PARASELENE_RESOURCE);\n" );
+			buf = buf.append( "pf.returnPage(page);\n" );
+
 			for ( int i = 0; i < cnt; i++ ) {
 				PrePage page = page_map.get( org_html.get( i ) );
 				buf = buf.append( "page=new " );
@@ -125,9 +157,20 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			new paraselene.mockup.output.source.base.PageLoader(),
 			new paraselene.mockup.output.source.base.PageType(),
 			new paraselene.mockup.output.source.base.Json(),
+			new paraselene.mockup.output.source.base.FormJson(),
 			new paraselene.mockup.output.source.base.Css(),
+			new paraselene.mockup.output.source.base.Js(),
+			new paraselene.mockup.output.source.base.Resource(),
+		};
+		String[]	name = {
+			"PageLoader.java",
+			"PageType.java",
+			"Json.java",
+			"FormJson.java",
+			"Css.java",
+			"Js.java",
+			"Resource.java",
 		};
-		String[]	name = { "PageLoader.java", "PageType.java", "Json.java", "Css.java" };
 		for ( int i = 0; i < name.length; i++ ) {
 			if ( output[i] == null )	continue;
 			StringBuilder    out_path = new StringBuilder( Make.SRC_PATH );
@@ -247,9 +290,11 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			page.makeSource();
 		}
 
-		makeBase();
-		makeWeb();
-		makeReadMe();
+		if ( Boolean.valueOf( Param.WEB_APP.get() ) ) {
+			makeBase();
+			makeWeb();
+			makeReadMe();
+		}
 	}
 
 	void setCurrentPage( PrePage p ) {
@@ -285,8 +330,13 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 	}
 
 	String resolvePath( URI uri ) throws Exception {
-		URIHandle	handle = new URIHandle( uri, URIHandle.URIProcess.FULL_PROCESS );
 		String	uri_str = uri.toString();
+		if ( !Boolean.valueOf( Param.WEB_APP.get() ) ) {
+			uri_str = URLDecoder.decode( uri_str, URIValue.DEFAULT_ENC );
+			return Make.escape( uri_str );
+		}
+
+		URIHandle	handle = new URIHandle( uri, URIHandle.URIProcess.FULL_PROCESS );
 		if ( Param.uri_pp != null ) {
 			URIHandle	handle_new = null;
 			try {
