@@ -7,13 +7,26 @@
 package paraselene.mockup;
 
 
+import paraselene.*;
 import java.io.*;
 
 public class SourceHead {
 	private static String head = "";
+	private static boolean init_f = false;
+
+	static {
+		StringBuilder	buf = new StringBuilder();
+		buf = buf.append( "// " );
+		buf = buf.append( Version.getTitle() );
+		buf = buf.append( " generated this source file." );
+		buf = buf.append( LineSeparator.getUse() );
+		head = buf.toString();
+	}
 
 	public static void init( File f ) throws FileNotFoundException, IOException {
-		StringBuilder	buf = new StringBuilder();
+		if ( init_f )	return;
+		init_f = true;
+		StringBuilder	buf = new StringBuilder( head );
 		BufferedReader	br = new BufferedReader(
 			new InputStreamReader( new FileInputStream( f ) )
 		);
@@ -27,8 +40,12 @@ public class SourceHead {
 		head = buf.toString();
 	}
 
-	public static String getHead() {
-		return head;
+	public static String getHead( File file ) {
+		String[]	part = file.getName().split( "\\." );
+		if ( part[part.length - 1].equals( "java" ) ) {
+			return head;
+		}
+		return "";
 	}
 }
 
