@@ -49,6 +49,7 @@ class HistorySet implements Serializable {
 		for ( int key: hist.keySet() ) {
 			remove( key );
 		}
+		Option.trace( "history all drop" );
 	}
 
 	synchronized private int newNo( int no ) {
@@ -59,6 +60,7 @@ class HistorySet implements Serializable {
 				continue;
 			}
 			hist.put( no, new History( no, session_id ) );
+			Option.trace( "issue history key %d", no );
 			return no;
 		}
 	}
