@@ -233,5 +233,98 @@ public class Option implements Serializable {
 			}
 		}
 	}
+
+	private static final String	MY_CLASS = "paraselene.supervisor.Option";
+	private static final String	CR = System.getProperty( "line.separator" );
+	private static volatile BufferedWriter	trace_writer = null;
+	private static Thread flusher = null;
+
+	private static void traceClose() {
+		try {
+			synchronized( MY_CLASS ) {
+				if ( trace_writer == null )	return;
+				trace_writer.close();
+				trace_writer = null;
+			}
+		}
+		catch( Exception e ) {}
+	}
+	private static void traceOpen( File log ) throws Exception {
+		synchronized( MY_CLASS ) {
+			if ( trace_writer != null )	return;
+			trace_writer = new BufferedWriter( new FileWriter( log ) );
+		}
+	}
+
+	/**
+	 * Paraselene 内部処理のログ出力。
+	 * 指定ファイルに処理のログを出力します。<br>
+	 * ファイルは初回出力時に 0 バイトに切り詰められ、以降追記され続けます。<br>
+	 * 再度ファイル名を渡しても無視され、初回指定時のファイルを使用し続けます。<br>
+	 * また、指定ファイルはオープンしたままとなります。<br>
+	 * 約10秒周期でファイルにフラッシュするため、書き込みが多少遅延します。
+	 * @param log 出力先ファイル名。null を渡すと、出力を停止します。
+	 */
+	public static void spy( String log ) {
+		if ( log == null ) {
+			traceClose();
+			return;
+		}
+		try {
+			traceOpen( new File( log ) );
+		}
+		catch( Exception e ) {	return; }
+		if ( flusher != null )	return;
+		flusher = new Thread() {
+			public void run() {
+				while( true ) {
+					try {
+						sleep( 1000 * 10 );
+						synchronized( MY_CLASS ) {
+							if ( trace_writer == null )	continue;
+							trace_writer.flush();
+						}
+					}catch(Exception e){}
+				}
+			}
+		};
+		flusher.setDaemon( true );
+		flusher.start();
+	}
+
+	private static void trace( String mes ) {
+		try {
+			synchronized( MY_CLASS ) {
+				if ( trace_writer == null )	return;
+				StackTraceElement[]	sta = Thread.currentThread().getStackTrace();
+				for ( int i = 1; i < sta.length; i++ ) {
+					if ( sta[i].getClassName().equals( MY_CLASS ) )	continue;
+					trace_writer.write( "■" );
+					trace_writer.write( new Date().toString() );
+					trace_writer.write( " " );
+					trace_writer.write( sta[i].toString() );
+					trace_writer.write( CR );
+					trace_writer.write( mes );
+					trace_writer.write( CR );
+					return;
+				}
+			}
+		}
+		catch( Exception e ) {}
+	}
+
+	static void append( String ... s ) {
+		if ( trace_writer == null )	return;
+		StringBuilder	buf = new StringBuilder();
+		for ( int i = 0; i < s.length; i++ ) {
+			buf = buf.append( s[i] );
+		}
+		trace( buf.toString() );
+	}
+
+	static void trace( String format, Object ... o ) {
+		if ( trace_writer == null )	return;
+		trace( String.format( format, o ) );
+	}
 }
 
