@@ -58,6 +58,7 @@ class OutputCall {
 			}
 		}
 		next_page.setRequestParameter( req );
+		Option.trace( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
 		Page	view = SandBox.output( next_page, last_page, req );
 		if ( view == null )	view = next_page;
 		next_page.setInitialized( false );
@@ -72,6 +73,7 @@ class OutputCall {
 		for ( int i = 0; i < ret.length; i++ ) {
 			ret[i] = new PostBack( data[i] );
 		}
+		Option.trace( "%s/%s to TagData JSON", next_page.getID(), next_page.getUniqueKey() );
 		return ret;
 	}
 }
@@ -92,18 +94,23 @@ class OpenOutput extends OutputCall {
 		Popup	p = (Popup)forward;
 		if ( p.active_page == null ) {
 			data.hist.get( next_key ).add( next_page );
+			Option.trace( "%s/%s to Popup open JSON", next_page.getID(), next_page.getUniqueKey() );
 			return new PostBack[] { new PostBack( new Open( out[1], false ) ) };
 		}
 		if ( p.active_page.getPopupType() != Popup.Type.MODELESS )	return new PostBack[0];
 		try {
 			Page[]	page = data.hist.get( next_key ).getBrowsingPage();
 			for ( int i = 0; i < page.length; i++ ) {
-				if ( page[i].getPopupType() == Popup.Type.MODAL )	return new PostBack[0];
+				if ( page[i].getPopupType() == Popup.Type.MODAL ) {
+					Option.trace( "%s/%s to Popup active cancel, because MODAL opened", next_page.getID(), next_page.getUniqueKey() );
+					return new PostBack[0];
+				}
 			}
 		}
 		finally {
 			data.hist.get( next_key ).unlock();
 		}
+		Option.trace( "%s/%s to Popup active JSON", next_page.getID(), next_page.getUniqueKey() );
 		return new PostBack[] { new PostBack( new Open( p.active_page, true ) ) };
 	}
 }
@@ -118,6 +125,7 @@ class CloseOutput extends OutputCall {
 	PostBack[] make() throws Exception {
 		Closure	c = (Closure)forward;
 		data.hist.get( next_key ).removePopup( c.close_page );
+		Option.trace( "%s/%s to Popup close JSON", next_page.getID(), next_page.getUniqueKey() );
 		return new PostBack[] { new PostBack( new Close( c.close_page ) ) };
 	}
 }
@@ -137,7 +145,9 @@ class LocationOutput extends OutputCall {
 		if ( !forward.isLeave() ) {
 			fw = data.redirect( out, forward, req );
 		}
-		return new PostBack[] { new PostBack( Supervisor.makeWithSessionURI( fw.getRedirectURI().toString(), null, null ) ) };
+		String	url = Supervisor.makeWithSessionURI( fw.getRedirectURI().toString(), null, null );
+		Option.trace( "%s redirect JSON", url );
+		return new PostBack[] { new PostBack( url ) };
 	}
 }
 
@@ -146,6 +156,7 @@ class OutputHolder {
 	private OutputCall[]	opc = null;
 
 	OutputHolder( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		Option.trace( "%s ajax %s", lp.getID(), lp.isAjax() );
 		AjaxForward[]	af = fw.getAjaxForward( lp.isAjax() );
 		if ( af != null ) {
 			forward = new Forward[af.length];
@@ -163,25 +174,31 @@ class OutputHolder {
 				if ( forward[i] instanceof Closure ) {
 					Closure	c = (Closure)forward[i];
 					if ( c.close_page.getPopupType() == null ) {
+						Option.trace( "new LocationOutput <- %s", forward[i] );
 						opc[i] = new LocationOutput( nk, lp, forward[i], r, sd );
 					}
 					else {
+						Option.trace( "new CloseOutput <- %s", forward[i] );
 						opc[i] = new CloseOutput( nk, lp, forward[i], r, sd );
 					}
 				}
 				else if ( forward[i] instanceof Feedback ) {
+					Option.trace( "new OutputCall <- %s", forward[i] );
 					opc[i] = new OutputCall( nk, lp, forward[i], r, sd );
 				}
 				else if ( forward[i] instanceof Popup ) {
+					Option.trace( "new OpenOutput <- %s", forward[i] );
 					Popup	p = (Popup)forward[i];
 					opc[i] = new OpenOutput( nk, lp, forward[i], p.getType(), r, sd );
 				}
 				else {
+					Option.trace( "new LocationOutput <- %s", forward[i] );
 					opc[i] = new LocationOutput( nk, lp, forward[i], r, sd );
 				}
 			}
 			return;
 		}
+		Option.trace( "new OutputCall <- %s", fw );
 		opc[0] = new OutputCall( nk, lp, fw, r, sd );
 	}
 
@@ -192,7 +209,8 @@ class OutputHolder {
 	}
 
 	Page[] getPage() {
-		return opc[0].getPage();
+		Page[]	p = opc[0].getPage();
+		return p;
 	}
 
 	Serializable[] getPostBack() throws Exception {
