@@ -11,6 +11,11 @@ import java.util.*;
 import paraselene.*;
 
 
+class AliasData {
+	Page	page = null;
+	Integer	to_histry = null;
+}
+
 /**
  * ページファクトリー。<br>
  * スレッドを生成し、バックグラウンドでPageインスタンスを事前準備して
@@ -196,7 +201,25 @@ public abstract class PageFactory extends Thread {
 		}
 	}
 
-	Page getPage( String uri ) {
+	private String parseAlias( String uri, AliasData data ) {
+		String[]	part = uri.split( "\\." );
+		if ( part.length < 4 )	return uri;
+		if ( TransactionSequencer.SELENE[5].equals( part[0] ) && TransactionSequencer.SELENE[6].equals( part[2] ) ) {
+			data.to_histry = Integer.parseInt( part[1], Character.MAX_RADIX );
+			StringBuilder	buf = new StringBuilder( part[3] );
+			for ( int i = 4; i < part.length; i++ ) {
+				buf = buf.append( "." );
+				buf = buf.append( part[i] );
+			}
+			uri = buf.toString();
+		}
+		return uri;
+	}
+
+	AliasData getPage( String uri ) {
+		if ( !Supervisor.isMyHost( uri ) )	return null;
+		AliasData	alias_data = new AliasData();
+		uri = parseAlias( uri, alias_data );
 		String[]	path = uri.split( "#" );
 		if ( path.length == 0 )	path = new String[] { uri };
 		path = path[0].split( "\\?" );
@@ -225,11 +248,21 @@ public abstract class PageFactory extends Thread {
 			}
 			if ( hit == null )	continue;
 			Integer	id = alias.get( hit );
-			if ( id != null )	return getPage( id.intValue() );
+			if ( id != null ) {
+				alias_data.page = getPage( id.intValue() );
+				return alias_data;
+			}
 		}
 		return null;
 	}
 
+	boolean isAlias( String uri ) {
+		AliasData	ret = getPage( uri );
+		if ( ret == null )	return false;
+		returnPage( ret.page );
+		return true;
+	}
+
 	/**
 	 * インスタンスの返却。未使用のページをファクトリーに戻します。
 	 * @param page 返却インスタンス。
