@@ -135,11 +135,12 @@ public class RequestParameter {
 	}
 
 	private HashMap<String,RequestItem>	item_map = new HashMap<String,RequestItem>();
-	private Method	method;
+	private Method	method = Method.GET;
 	private URI	uri = null;
+	private URI	sub_uri = null;
 	private HttpSession	session = null;
-	private Cookie[]	in_cookie;
-	private String	remote_addr;
+	private Cookie[]	in_cookie = null;
+	private String	remote_addr = null;
 	private HashMap<String,String[]>	header = new HashMap<String,String[]>();
 	private Supervisor	supervisor = null;
 	static final String UA_HEAD = "User-Agent";
@@ -170,6 +171,12 @@ public class RequestParameter {
 	 * コンストラクタ。
 	 */
 	public RequestParameter() {
+		try {
+			uri = new URI( "#" );
+		}
+		catch( Exception e ) {
+			Option.debug( e );
+		}
 	}
 
 	/**
@@ -212,6 +219,14 @@ public class RequestParameter {
 		uri = u;
 	}
 
+	/**
+	 * リクエストURI設定。コンテキストパスを含まない、相対パスです。
+	 * @param u URI。
+	 */
+	protected void setRelativeURI( URI u ) {
+		sub_uri = u;
+	}
+
 	/**
 	 * サーブレット設定。
 	 * @param sv サーブレット。
@@ -243,8 +258,25 @@ public class RequestParameter {
 				buf = buf.append( query );
 			}
 			setURI( new URI( buf.toString() ) );
+
+			String[]	path = getURI().getPath().split( "/" );
+			String[]	cont = request.getContextPath().split( "/" );
+			String	last = cont[cont.length - 1];
+			int	start = 0;
+			for ( ; start < path.length; start++ ) {
+				if ( last.equals( path[start] ) )	break;
+			}
+			start++;
+			StringBuilder	b = new StringBuilder( path[start] );
+			for ( start++; start < path.length; start++ ) {
+				b = b.append( "/" );
+				b = b.append( path[start] );
+			}
+			setRelativeURI( new URI( b.toString() ) );
+		}
+		catch(Exception e){
+			Option.debug( e );
 		}
-		catch(Exception e){}
 		for ( Enumeration<?>	em = request.getHeaderNames(); em.hasMoreElements(); ) {
 			String	key = (String)em.nextElement();
 			ArrayList<String>	data = new ArrayList<String>();
@@ -352,6 +384,14 @@ public class RequestParameter {
 		return uri;
 	}
 
+	/**
+	 * リクエストされたURIの取得。
+	 * @return URI。
+	 */
+	public URI getRelativeURI() {
+		return sub_uri;
+	}
+
 	/**
 	 * クッキーの取得。
 	 * @return 全てのクッキー。
@@ -435,6 +475,21 @@ public class RequestParameter {
 		return session;
 	}
 
+	/**
+	 * 履歴キーの問い合わせ。
+	 * 指定された name 属性を持つウィンドウ(フレーム)に割り当てられた
+	 * 画面遷移履歴キーを返します。<br>
+	 * 画面遷移履歴キーは正数です。
+	 * @param name ウィンドウ(フレーム)の name 属性。
+	 * @return 画面遷移履歴キー。name が未登録であれば -1。
+	 */
+	public int getHistoryKey( String name ) {
+		HttpSession	session = getSession();
+		if ( session == null )	return -1;
+		SessionData	data = (SessionData)session.getAttribute( Supervisor.SESSION_DATA );
+		return data.hist.getKey( name );
+	}
+
 	/**
 	 * 履歴の取得。
 	 * @param key 画面遷移履歴キー。
@@ -444,6 +499,7 @@ public class RequestParameter {
 		HttpSession	session = getSession();
 		if ( session == null )	return null;
 		SessionData	data = (SessionData)session.getAttribute( Supervisor.SESSION_DATA );
+		if ( data == null )	return null;
 		return data.hist.get( key );
 	}
 
