@@ -289,6 +289,7 @@ public abstract class Supervisor extends HttpServlet {
 	private static void clear_session( HttpSession s ) {
 //Thread.dumpStack();
 		s.invalidate();
+		Option.trace( "session cleared" );
 	}
 
 	/**
@@ -461,7 +462,9 @@ public abstract class Supervisor extends HttpServlet {
 				int	from_key = HistorySet.ROOT;
 				int	to_key = HistorySet.ROOT;
 				if ( path_data.from_histry != null )	from_key = path_data.from_histry;
-				if ( path_data.to_histry != null )	to_key = path_data.to_histry;
+				if ( path_data.to_histry != null ){
+					to_key = path_data.to_histry;
+				}
 				if ( next_page != null ) {
 					if ( from_key != to_key ) {
 						fw = new Forward( next_page.getID(), true, false );
@@ -486,12 +489,17 @@ public abstract class Supervisor extends HttpServlet {
 				}
 				last_page.setRequestParameter( req );
 				last_page.reflect( req );
+				Option.trace( "%s input(%s) call", last_page.getID(), fw );
 				fw = SandBox.input( last_page, req, fw );
+				session = req.getSession();
+				Option.trace( "%s input return %s", last_page.getID(), fw );
 				last_page.setInitialized( false );
 				last_page.setRequestParameter( null );
 				session_f = fw.session_clear_f;
 				if ( fw.getPageID() == Closure.CLOSE ) {
+					Forward	old = fw;
 					fw = new Feedback( last_page );
+					Option.trace( "%s to %s", old, fw );
 				}
 				if ( (!last_page.isAjax() && fw.isLeave()) || fw.getStatus() != 0 ) {
 					fw.Action( this, res );
@@ -537,6 +545,7 @@ public abstract class Supervisor extends HttpServlet {
 				fw.Action( this, res );
 				return;
 			}
+			Option.trace( "no ajax result %s/%s", out_ret[1].getID(), out_ret[1].getUniqueKey() );
 			write( out_ret, session_f, fw, holder );
 		}
 		catch( Throwable e ) {
@@ -559,7 +568,9 @@ public abstract class Supervisor extends HttpServlet {
 		}
 		if ( holder == null )	return old;
 		if ( old != null ) {
+			if ( holder.data != null )	holder.data.planed_clear = true;
 			clear_session( old );
+			if ( holder.data != null )	holder.data.planed_clear = false;
 		}
 		HttpSession	session = holder.req.getSession( true );
 		session.setAttribute( SESSION_DATA, holder.data );
