@@ -52,7 +52,7 @@ public class Button extends Input {
 	}
 
 	protected Tag newReplica() {
-		return new Button( const_type );
+		return copy4Replica( new Button( const_type ) );
 	}
 
 	void setPushed( boolean flag ) {
