@@ -52,7 +52,7 @@ public class Select extends Control {
 	}
 
 	protected Tag newReplica() {
-		return new Select();
+		return copy4Replica( new Select() );
 	}
 
 	private void setup( HTMLPart d ) {
